/*
 * Copyright 2018 NXP
 * All rights reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */
 

#ifndef _PIN_MUX_H_
#define _PIN_MUX_H_

/***********************************************************************************************************************
 * Definitions
 **********************************************************************************************************************/

/*! @brief Direction type  */
typedef enum _pin_mux_direction
{
    kPIN_MUX_DirectionInput = 0U,        /* Input direction */
    kPIN_MUX_DirectionOutput = 1U,       /* Output direction */
    kPIN_MUX_DirectionInputOrOutput = 2U /* Input or output direction */
} pin_mux_direction_t;

/*!
 * @addtogroup pin_mux
 * @{
 */

/***********************************************************************************************************************
 * API
 **********************************************************************************************************************/

#if defined(__cplusplus)
extern "C" {
#endif

/*!
 * @brief Calls initialization functions.
 *
 */
void BOARD_InitBootPins(void);

/*!
 * @brief Configures pin routing and optionally pin electrical features.
 *
 */
void BOARD_InitPins(void); /* Function assigned for the Cortex-M4F */

#define PIO04_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO04_FUNC_ALT0 0x00u        /*!<@brief Selects pin function.: Alternative connection 0. */
#define PIO05_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO05_FUNC_ALT0 0x00u        /*!<@brief Selects pin function.: Alternative connection 0. */
#define PIO06_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO06_FUNC_ALT0 0x00u        /*!<@brief Selects pin function.: Alternative connection 0. */
#define PIO11_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO11_FUNC_ALT0 0x00u        /*!<@brief Selects pin function.: Alternative connection 0. */

/*! @name PIO0_6 (coord A5), U28[C8]/RP5[4]/SW2/P0_6-ISP2/P0_6-EMC_D4
  @{ */
#define BOARD_SW2_PERIPHERAL GPIO                                  /*!<@brief Device name: GPIO */
#define BOARD_SW2_SIGNAL PIO0                                      /*!<@brief GPIO signal: PIO0 */
#define BOARD_SW2_GPIO GPIO                                        /*!<@brief GPIO device name: GPIO */
#define BOARD_SW2_GPIO_PIN 6U                                      /*!<@brief PIO0 pin index: 6 */
#define BOARD_SW2_PORT 0U                                          /*!<@brief PORT device name: 0U */
#define BOARD_SW2_PIN 6U                                           /*!<@brief 0U pin index: 6 */
#define BOARD_SW2_CHANNEL 6                                        /*!<@brief GPIO PIO0 channel: 6 */
#define BOARD_SW2_PIN_NAME PIO0_6                                  /*!<@brief Pin name */
#define BOARD_SW2_LABEL "U28[C8]/RP5[4]/SW2/P0_6-ISP2/P0_6-EMC_D4" /*!<@brief Label */
#define BOARD_SW2_NAME "SW2"                                       /*!<@brief Identifier name */
#define BOARD_SW2_DIRECTION kPIN_MUX_DirectionInput                /*!<@brief Direction */
                                                                   /* @} */

/*! @name PIO0_5 (coord E7), U28[C9]/RP3[1]/JS32[1]/SW3/P0_5-ISP1/P0_5-EMC_D3
  @{ */
/*!
 * @brief Device name: GPIO */
#define BOARD_SW3_PERIPHERAL GPIO
/*!
 * @brief GPIO signal: PIO0 */
#define BOARD_SW3_SIGNAL PIO0
/*!
 * @brief GPIO device name: GPIO */
#define BOARD_SW3_GPIO GPIO
/*!
 * @brief PIO0 pin index: 5 */
#define BOARD_SW3_GPIO_PIN 5U
/*!
 * @brief PORT device name: 0U */
#define BOARD_SW3_PORT 0U
/*!
 * @brief 0U pin index: 5 */
#define BOARD_SW3_PIN 5U
/*!
 * @brief GPIO PIO0 channel: 5 */
#define BOARD_SW3_CHANNEL 5
/*!
 * @brief Pin name */
#define BOARD_SW3_PIN_NAME PIO0_5
/*!
 * @brief Label */
#define BOARD_SW3_LABEL "U28[C9]/RP3[1]/JS32[1]/SW3/P0_5-ISP1/P0_5-EMC_D3"
/*!
 * @brief Identifier name */
#define BOARD_SW3_NAME "SW3"
/*!
 * @brief Direction */
#define BOARD_SW3_DIRECTION kPIN_MUX_DirectionInput
/* @} */

/*! @name PIO0_4 (coord C8), U28[B8]/RP3[2]/JS32[3]/SW4/P0_4-ISP0/P0_4-EMC_D2
  @{ */
/*!
 * @brief Device name: GPIO */
#define BOARD_SW4_PERIPHERAL GPIO
/*!
 * @brief GPIO signal: PIO0 */
#define BOARD_SW4_SIGNAL PIO0
/*!
 * @brief GPIO device name: GPIO */
#define BOARD_SW4_GPIO GPIO
/*!
 * @brief PIO0 pin index: 4 */
#define BOARD_SW4_GPIO_PIN 4U
/*!
 * @brief PORT device name: 0U */
#define BOARD_SW4_PORT 0U
/*!
 * @brief 0U pin index: 4 */
#define BOARD_SW4_PIN 4U
/*!
 * @brief GPIO PIO0 channel: 4 */
#define BOARD_SW4_CHANNEL 4
/*!
 * @brief Pin name */
#define BOARD_SW4_PIN_NAME PIO0_4
/*!
 * @brief Label */
#define BOARD_SW4_LABEL "U28[B8]/RP3[2]/JS32[3]/SW4/P0_4-ISP0/P0_4-EMC_D2"
/*!
 * @brief Identifier name */
#define BOARD_SW4_NAME "SW4"
/*!
 * @brief Direction */
#define BOARD_SW4_DIRECTION kPIN_MUX_DirectionInput
/* @} */

/*! @name PIO1_1 (coord K12), J12[12]/U29[4]/SW5/P1_1-USER_PB-USB1_OVRCURn
  @{ */
#define BOARD_SW5_PERIPHERAL GPIO                                      /*!<@brief Device name: GPIO */
#define BOARD_SW5_SIGNAL PIO1                                          /*!<@brief GPIO signal: PIO1 */
#define BOARD_SW5_GPIO GPIO                                            /*!<@brief GPIO device name: GPIO */
#define BOARD_SW5_GPIO_PIN 1U                                          /*!<@brief PIO1 pin index: 1 */
#define BOARD_SW5_PORT 1U                                              /*!<@brief PORT device name: 1U */
#define BOARD_SW5_PIN 1U                                               /*!<@brief 1U pin index: 1 */
#define BOARD_SW5_CHANNEL 1                                            /*!<@brief GPIO PIO1 channel: 1 */
#define BOARD_SW5_PIN_NAME PIO1_1                                      /*!<@brief Pin name */
#define BOARD_SW5_LABEL "J12[12]/U29[4]/SW5/P1_1-USER_PB-USB1_OVRCURn" /*!<@brief Label */
#define BOARD_SW5_NAME "SW5"                                           /*!<@brief Identifier name */
#define BOARD_SW5_DIRECTION kPIN_MUX_DirectionInput                    /*!<@brief Direction */
                                                                       /* @} */

/*!
 * @brief Configures pin routing and optionally pin electrical features.
 *
 */
void BOARD_InitBUTTONs(void); /* Function assigned for the Cortex-M4F */

#define PIO22_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO22_FUNC_ALT0 0x00u         /*!<@brief Selects pin function.: Alternative connection 0. */
#define PIO314_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO314_FUNC_ALT0 0x00u        /*!<@brief Selects pin function.: Alternative connection 0. */
#define PIO33_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO33_FUNC_ALT0 0x00u         /*!<@brief Selects pin function.: Alternative connection 0. */

/*! @name PIO3_3 (coord A13), J9[8]/LED2/P3_3-USR_LED2
  @{ */
#define BOARD_LED2_PERIPHERAL GPIO                    /*!<@brief Device name: GPIO */
#define BOARD_LED2_SIGNAL PIO3                        /*!<@brief GPIO signal: PIO3 */
#define BOARD_LED2_GPIO GPIO                          /*!<@brief GPIO device name: GPIO */
#define BOARD_LED2_GPIO_PIN 3U                        /*!<@brief PIO3 pin index: 3 */
#define BOARD_LED2_PORT 3U                            /*!<@brief PORT device name: 3U */
#define BOARD_LED2_PIN 3U                             /*!<@brief 3U pin index: 3 */
#define BOARD_LED2_CHANNEL 3                          /*!<@brief GPIO PIO3 channel: 3 */
#define BOARD_LED2_PIN_NAME PIO3_3                    /*!<@brief Pin name */
#define BOARD_LED2_LABEL "J9[8]/LED2/P3_3-USR_LED2"   /*!<@brief Label */
#define BOARD_LED2_NAME "LED2"                        /*!<@brief Identifier name */
#define BOARD_LED2_DIRECTION kPIN_MUX_DirectionOutput /*!<@brief Direction */
                                                      /* @} */

/*! @name PIO2_2 (coord C3), J9[6]/LED3/P2_2-CT1MAT1-USR_LED3
  @{ */
#define BOARD_LED3_PERIPHERAL GPIO                          /*!<@brief Device name: GPIO */
#define BOARD_LED3_SIGNAL PIO2                              /*!<@brief GPIO signal: PIO2 */
#define BOARD_LED3_GPIO GPIO                                /*!<@brief GPIO device name: GPIO */
#define BOARD_LED3_GPIO_PIN 2U                              /*!<@brief PIO2 pin index: 2 */
#define BOARD_LED3_PORT 2U                                  /*!<@brief PORT device name: 2U */
#define BOARD_LED3_PIN 2U                                   /*!<@brief 2U pin index: 2 */
#define BOARD_LED3_CHANNEL 2                                /*!<@brief GPIO PIO2 channel: 2 */
#define BOARD_LED3_PIN_NAME PIO2_2                          /*!<@brief Pin name */
#define BOARD_LED3_LABEL "J9[6]/LED3/P2_2-CT1MAT1-USR_LED3" /*!<@brief Label */
#define BOARD_LED3_NAME "LED3"                              /*!<@brief Identifier name */
#define BOARD_LED3_DIRECTION kPIN_MUX_DirectionOutput       /*!<@brief Direction */
                                                            /* @} */

/*! @name PIO3_14 (coord E3), J13[5]/LED1/P3_14-CT3MAT1-USR_LED1
  @{ */
#define BOARD_LED1_PERIPHERAL GPIO                            /*!<@brief Device name: GPIO */
#define BOARD_LED1_SIGNAL PIO3                                /*!<@brief GPIO signal: PIO3 */
#define BOARD_LED1_GPIO GPIO                                  /*!<@brief GPIO device name: GPIO */
#define BOARD_LED1_GPIO_PIN 14U                               /*!<@brief PIO3 pin index: 14 */
#define BOARD_LED1_PORT 3U                                    /*!<@brief PORT device name: 3U */
#define BOARD_LED1_PIN 14U                                    /*!<@brief 3U pin index: 14 */
#define BOARD_LED1_CHANNEL 14                                 /*!<@brief GPIO PIO3 channel: 14 */
#define BOARD_LED1_PIN_NAME PIO3_14                           /*!<@brief Pin name */
#define BOARD_LED1_LABEL "J13[5]/LED1/P3_14-CT3MAT1-USR_LED1" /*!<@brief Label */
#define BOARD_LED1_NAME "LED1"                                /*!<@brief Identifier name */
#define BOARD_LED1_DIRECTION kPIN_MUX_DirectionOutput         /*!<@brief Direction */
                                                              /* @} */

/*!
 * @brief Configures pin routing and optionally pin electrical features.
 *
 */
void BOARD_InitLEDs(void); /* Function assigned for the Cortex-M4F */

#define PIO00_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO00_FUNC_ALT2 0x02u         /*!<@brief Selects pin function.: Alternative connection 2. */
#define PIO013_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO013_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO014_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO014_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO01_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO01_FUNC_ALT2 0x02u         /*!<@brief Selects pin function.: Alternative connection 2. */
#define PIO02_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO02_FUNC_ALT1 0x01u         /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO03_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO03_FUNC_ALT1 0x01u         /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO313_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO313_FUNC_ALT0 0x00u        /*!<@brief Selects pin function.: Alternative connection 0. */

/*! @name FC3_CTS_SDA_SSEL0 (coord A1), U26[14]/J14[1]/P0_1-ISP_FC3_SSEL0
  @{ */
#define BOARD_ISP_FC3_SSEL0_PERIPHERAL FLEXCOMM3                      /*!<@brief Device name: FLEXCOMM3 */
#define BOARD_ISP_FC3_SSEL0_SIGNAL CTS_SDA_SSEL0                      /*!<@brief FLEXCOMM3 signal: CTS_SDA_SSEL0 */
#define BOARD_ISP_FC3_SSEL0_PIN_NAME FC3_CTS_SDA_SSEL0                /*!<@brief Pin name */
#define BOARD_ISP_FC3_SSEL0_LABEL "U26[14]/J14[1]/P0_1-ISP_FC3_SSEL0" /*!<@brief Label */
#define BOARD_ISP_FC3_SSEL0_NAME "ISP_FC3_SSEL0"                      /*!<@brief Identifier name */
#define BOARD_ISP_FC3_SSEL0_DIRECTION kPIN_MUX_DirectionOutput        /*!<@brief Direction */
                                                                      /* @} */

/*! @name FC3_RXD_SDA_MOSI (coord A10), U28[B9]/RP3[3]/JS34[1]/U26[11]/J14[2]/P0_3-ISP_FC3_MOSI/P0_3-EMC_D1
  @{ */
/*!
 * @brief Device name: FLEXCOMM3 */
#define BOARD_ISP_FC3_MOSI_PERIPHERAL FLEXCOMM3
/*!
 * @brief FLEXCOMM3 signal: RXD_SDA_MOSI */
#define BOARD_ISP_FC3_MOSI_SIGNAL RXD_SDA_MOSI
/*!
 * @brief Pin name */
#define BOARD_ISP_FC3_MOSI_PIN_NAME FC3_RXD_SDA_MOSI
/*!
 * @brief Label */
#define BOARD_ISP_FC3_MOSI_LABEL "U28[B9]/RP3[3]/JS34[1]/U26[11]/J14[2]/P0_3-ISP_FC3_MOSI/P0_3-EMC_D1"
/*!
 * @brief Identifier name */
#define BOARD_ISP_FC3_MOSI_NAME "ISP_FC3_MOSI"
/*!
 * @brief Direction */
#define BOARD_ISP_FC3_MOSI_DIRECTION kPIN_MUX_DirectionOutput
/* @} */

/*! @name FC3_TXD_SCL_MISO (coord E9), U28[A8]/RP3[4]/JS35[1]/U24[11]/J14[3]/P0_2-ISP_FC3_MISO/P0_2-EMC_D0
  @{ */
/*!
 * @brief Device name: FLEXCOMM3 */
#define BOARD_ISP_FC3_MISO_PERIPHERAL FLEXCOMM3
/*!
 * @brief FLEXCOMM3 signal: TXD_SCL_MISO */
#define BOARD_ISP_FC3_MISO_SIGNAL TXD_SCL_MISO
/*!
 * @brief Pin name */
#define BOARD_ISP_FC3_MISO_PIN_NAME FC3_TXD_SCL_MISO
/*!
 * @brief Label */
#define BOARD_ISP_FC3_MISO_LABEL "U28[A8]/RP3[4]/JS35[1]/U24[11]/J14[3]/P0_2-ISP_FC3_MISO/P0_2-EMC_D0"
/*!
 * @brief Identifier name */
#define BOARD_ISP_FC3_MISO_NAME "ISP_FC3_MISO"
/*!
 * @brief Direction */
#define BOARD_ISP_FC3_MISO_DIRECTION kPIN_MUX_DirectionInput
/* @} */

/*! @name FC3_SCK (coord D6), U26[13]/J14[4]/P0_0-ISP_FC3_SCK
  @{ */
#define BOARD_ISP_FC3_SCK_PERIPHERAL FLEXCOMM3                    /*!<@brief Device name: FLEXCOMM3 */
#define BOARD_ISP_FC3_SCK_SIGNAL SCK                              /*!<@brief FLEXCOMM3 signal: SCK */
#define BOARD_ISP_FC3_SCK_PIN_NAME FC3_SCK                        /*!<@brief Pin name */
#define BOARD_ISP_FC3_SCK_LABEL "U26[13]/J14[4]/P0_0-ISP_FC3_SCK" /*!<@brief Label */
#define BOARD_ISP_FC3_SCK_NAME "ISP_FC3_SCK"                      /*!<@brief Identifier name */
#define BOARD_ISP_FC3_SCK_DIRECTION kPIN_MUX_DirectionOutput      /*!<@brief Direction */
                                                                  /* @} */

/*! @name PIO3_13 (coord H4), J14[8]/P3_13-BRIDGE_GPIO
  @{ */
#define BOARD_BRIDGE_GPIO_PERIPHERAL GPIO                  /*!<@brief Device name: GPIO */
#define BOARD_BRIDGE_GPIO_SIGNAL PIO3                      /*!<@brief GPIO signal: PIO3 */
#define BOARD_BRIDGE_GPIO_GPIO GPIO                        /*!<@brief GPIO device name: GPIO */
#define BOARD_BRIDGE_GPIO_GPIO_PIN 13U                     /*!<@brief PIO3 pin index: 13 */
#define BOARD_BRIDGE_GPIO_PORT 3U                          /*!<@brief PORT device name: 3U */
#define BOARD_BRIDGE_GPIO_PIN 13U                          /*!<@brief 3U pin index: 13 */
#define BOARD_BRIDGE_GPIO_CHANNEL 13                       /*!<@brief GPIO PIO3 channel: 13 */
#define BOARD_BRIDGE_GPIO_PIN_NAME PIO3_13                 /*!<@brief Pin name */
#define BOARD_BRIDGE_GPIO_LABEL "J14[8]/P3_13-BRIDGE_GPIO" /*!<@brief Label */
#define BOARD_BRIDGE_GPIO_NAME "BRIDGE_GPIO"               /*!<@brief Identifier name */
                                                           /* @} */

/*! @name FC1_CTS_SDA_SSEL0 (coord F11), JS16[2]/J14[9]/P0_13-ISP_FC1_SDAX
  @{ */
#define BOARD_ISP_FC1_SDAX_PERIPHERAL FLEXCOMM1                      /*!<@brief Device name: FLEXCOMM1 */
#define BOARD_ISP_FC1_SDAX_SIGNAL CTS_SDA_SSEL0                      /*!<@brief FLEXCOMM1 signal: CTS_SDA_SSEL0 */
#define BOARD_ISP_FC1_SDAX_PIN_NAME FC1_CTS_SDA_SSEL0                /*!<@brief Pin name */
#define BOARD_ISP_FC1_SDAX_LABEL "JS16[2]/J14[9]/P0_13-ISP_FC1_SDAX" /*!<@brief Label */
#define BOARD_ISP_FC1_SDAX_NAME "ISP_FC1_SDAX"                       /*!<@brief Identifier name */
                                                                     /* @} */

/*! @name FC1_RTS_SCL_SSEL1 (coord E13), JS15[2]/J14[10]/P0_14-ISP_FC1_SCLX
  @{ */
#define BOARD_ISP_FC1_SCLX_PERIPHERAL FLEXCOMM1                       /*!<@brief Device name: FLEXCOMM1 */
#define BOARD_ISP_FC1_SCLX_SIGNAL RTS_SCL_SSEL1                       /*!<@brief FLEXCOMM1 signal: RTS_SCL_SSEL1 */
#define BOARD_ISP_FC1_SCLX_PIN_NAME FC1_RTS_SCL_SSEL1                 /*!<@brief Pin name */
#define BOARD_ISP_FC1_SCLX_LABEL "JS15[2]/J14[10]/P0_14-ISP_FC1_SCLX" /*!<@brief Label */
#define BOARD_ISP_FC1_SCLX_NAME "ISP_FC1_SCLX"                        /*!<@brief Identifier name */
                                                                      /* @} */

/*!
 * @brief Configures pin routing and optionally pin electrical features.
 *
 */
void BOARD_InitPMod_SPI_I2C_BRIDGE(void); /* Function assigned for the Cortex-M4F */

#define PIO323_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO323_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO324_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO324_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO34_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO34_FUNC_ALT0 0x00u         /*!<@brief Selects pin function.: Alternative connection 0. */

/*! @name FC2_CTS_SDA_SSEL0 (coord C2), J11[10]/J9[3]/U10[3]/J17[5]/U19[10]/P3_23-FC2_SDAX
  @{ */
/*!
 * @brief Device name: FLEXCOMM2 */
#define BOARD_FC2_SDAX_PERIPHERAL FLEXCOMM2
/*!
 * @brief FLEXCOMM2 signal: CTS_SDA_SSEL0 */
#define BOARD_FC2_SDAX_SIGNAL CTS_SDA_SSEL0
/*!
 * @brief Pin name */
#define BOARD_FC2_SDAX_PIN_NAME FC2_CTS_SDA_SSEL0
/*!
 * @brief Label */
#define BOARD_FC2_SDAX_LABEL "J11[10]/J9[3]/U10[3]/J17[5]/U19[10]/P3_23-FC2_SDAX"
/*!
 * @brief Identifier name */
#define BOARD_FC2_SDAX_NAME "FC2_SDAX"
/* @} */

/*! @name FC2_RTS_SCL_SSEL1 (coord E2), J11[9]/J9[1]/U10[2]/J17[4]/U19[2]/P3_24-FC2_SCLX
  @{ */
/*!
 * @brief Device name: FLEXCOMM2 */
#define BOARD_FC2_SCLX_PERIPHERAL FLEXCOMM2
/*!
 * @brief FLEXCOMM2 signal: RTS_SCL_SSEL1 */
#define BOARD_FC2_SCLX_SIGNAL RTS_SCL_SSEL1
/*!
 * @brief Pin name */
#define BOARD_FC2_SCLX_PIN_NAME FC2_RTS_SCL_SSEL1
/*!
 * @brief Label */
#define BOARD_FC2_SCLX_LABEL "J11[9]/J9[1]/U10[2]/J17[4]/U19[2]/P3_24-FC2_SCLX"
/*!
 * @brief Identifier name */
#define BOARD_FC2_SCLX_NAME "FC2_SCLX"
/* @} */

/*! @name PIO3_4 (coord B11), J12[10]/U19[3]/P3_4-ACCL_INTR
  @{ */
#define BOARD_ACCL_INTR_PERIPHERAL GPIO                       /*!<@brief Device name: GPIO */
#define BOARD_ACCL_INTR_SIGNAL PIO3                           /*!<@brief GPIO signal: PIO3 */
#define BOARD_ACCL_INTR_GPIO GPIO                             /*!<@brief GPIO device name: GPIO */
#define BOARD_ACCL_INTR_GPIO_PIN 4U                           /*!<@brief PIO3 pin index: 4 */
#define BOARD_ACCL_INTR_PORT 3U                               /*!<@brief PORT device name: 3U */
#define BOARD_ACCL_INTR_PIN 4U                                /*!<@brief 3U pin index: 4 */
#define BOARD_ACCL_INTR_CHANNEL 4                             /*!<@brief GPIO PIO3 channel: 4 */
#define BOARD_ACCL_INTR_PIN_NAME PIO3_4                       /*!<@brief Pin name */
#define BOARD_ACCL_INTR_LABEL "J12[10]/U19[3]/P3_4-ACCL_INTR" /*!<@brief Label */
#define BOARD_ACCL_INTR_NAME "ACCL_INTR"                      /*!<@brief Identifier name */
#define BOARD_ACCL_INTR_DIRECTION kPIN_MUX_DirectionInput     /*!<@brief Direction */
                                                              /* @} */

/*!
 * @brief Configures pin routing and optionally pin electrical features.
 *
 */
void BOARD_InitACCEL(void); /* Function assigned for the Cortex-M4F */

#define PIO023_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO023_FUNC_ALT6 0x06u        /*!<@brief Selects pin function.: Alternative connection 6. */
#define PIO024_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO024_FUNC_ALT6 0x06u        /*!<@brief Selects pin function.: Alternative connection 6. */
#define PIO025_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO025_FUNC_ALT6 0x06u        /*!<@brief Selects pin function.: Alternative connection 6. */
#define PIO026_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO026_FUNC_ALT6 0x06u        /*!<@brief Selects pin function.: Alternative connection 6. */
#define PIO027_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO027_FUNC_ALT6 0x06u        /*!<@brief Selects pin function.: Alternative connection 6. */
#define PIO028_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO028_FUNC_ALT6 0x06u        /*!<@brief Selects pin function.: Alternative connection 6. */
#define PIO212_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO212_FUNC_ALT0 0x00u        /*!<@brief Selects pin function.: Alternative connection 0. */

/*! @name SPIFI_CLK (coord M13), J13[2]/U27[6]/P0_26-SPIFI_CLK
  @{ */
#define BOARD_SPIFI_CLK_PERIPHERAL SPIFI0                     /*!<@brief Device name: SPIFI0 */
#define BOARD_SPIFI_CLK_SIGNAL SPIFI_SCK                      /*!<@brief SPIFI0 signal: SPIFI_SCK */
#define BOARD_SPIFI_CLK_PIN_NAME SPIFI_CLK                    /*!<@brief Pin name */
#define BOARD_SPIFI_CLK_LABEL "J13[2]/U27[6]/P0_26-SPIFI_CLK" /*!<@brief Label */
#define BOARD_SPIFI_CLK_NAME "SPIFI_CLK"                      /*!<@brief Identifier name */
                                                              /* @} */

/*! @name SPIFI_IO(0) (coord M7), J13[6]/U27[5]/P0_24-SPIFI_IO0
  @{ */
#define BOARD_SPIFI_IO0_PERIPHERAL SPIFI0                     /*!<@brief Device name: SPIFI0 */
#define BOARD_SPIFI_IO0_SIGNAL SPIFI_IO0/SPIFI_MOSI           /*!<@brief SPIFI0 signal: SPIFI_IO0/SPIFI_MOSI */
#define BOARD_SPIFI_IO0_PIN_NAME SPIFI_IO(0)                  /*!<@brief Pin name */
#define BOARD_SPIFI_IO0_LABEL "J13[6]/U27[5]/P0_24-SPIFI_IO0" /*!<@brief Label */
#define BOARD_SPIFI_IO0_NAME "SPIFI_IO0"                      /*!<@brief Identifier name */
                                                              /* @} */

/*! @name SPIFI_IO(1) (coord K8), J13[4]/U27[2]/P0_25-SPIFI_IO1
  @{ */
#define BOARD_SPIFI_IO1_PERIPHERAL SPIFI0                     /*!<@brief Device name: SPIFI0 */
#define BOARD_SPIFI_IO1_SIGNAL SPIFI_IO1/SPIFI_MISO           /*!<@brief SPIFI0 signal: SPIFI_IO1/SPIFI_MISO */
#define BOARD_SPIFI_IO1_PIN_NAME SPIFI_IO(1)                  /*!<@brief Pin name */
#define BOARD_SPIFI_IO1_LABEL "J13[4]/U27[2]/P0_25-SPIFI_IO1" /*!<@brief Label */
#define BOARD_SPIFI_IO1_NAME "SPIFI_IO1"                      /*!<@brief Identifier name */
                                                              /* @} */

/*! @name SPIFI_IO(3) (coord L9), J13[12]/U27[7]/P0_27-SPIFI_IO3
  @{ */
#define BOARD_SPIFI_IO3_PERIPHERAL SPIFI0                      /*!<@brief Device name: SPIFI0 */
#define BOARD_SPIFI_IO3_SIGNAL SPIFI_IO                        /*!<@brief SPIFI0 signal: SPIFI_IO */
#define BOARD_SPIFI_IO3_CHANNEL 3                              /*!<@brief SPIFI0 SPIFI_IO channel: 3 */
#define BOARD_SPIFI_IO3_PIN_NAME SPIFI_IO(3)                   /*!<@brief Pin name */
#define BOARD_SPIFI_IO3_LABEL "J13[12]/U27[7]/P0_27-SPIFI_IO3" /*!<@brief Label */
#define BOARD_SPIFI_IO3_NAME "SPIFI_IO3"                       /*!<@brief Identifier name */
                                                               /* @} */

/*! @name SPIFI_IO(2) (coord M9), J13[10]/U27[3]/P0_28-SPIFI_IO2-USB0_OCURRn
  @{ */
/*!
 * @brief Device name: SPIFI0 */
#define BOARD_SPIFI_IO2_PERIPHERAL SPIFI0
/*!
 * @brief SPIFI0 signal: SPIFI_IO */
#define BOARD_SPIFI_IO2_SIGNAL SPIFI_IO
/*!
 * @brief SPIFI0 SPIFI_IO channel: 2 */
#define BOARD_SPIFI_IO2_CHANNEL 2
/*!
 * @brief Pin name */
#define BOARD_SPIFI_IO2_PIN_NAME SPIFI_IO(2)
/*!
 * @brief Label */
#define BOARD_SPIFI_IO2_LABEL "J13[10]/U27[3]/P0_28-SPIFI_IO2-USB0_OCURRn"
/*!
 * @brief Identifier name */
#define BOARD_SPIFI_IO2_NAME "SPIFI_IO2"
/* @} */

/*! @name SPIFI_CSN (coord N7), J13[8]/U27[1]/P0_23-SPIFI_CSn-MCLK
  @{ */
#define BOARD_SPIFI_CSn_PERIPHERAL SPIFI0                          /*!<@brief Device name: SPIFI0 */
#define BOARD_SPIFI_CSn_SIGNAL SPIFI_CSN                           /*!<@brief SPIFI0 signal: SPIFI_CSN */
#define BOARD_SPIFI_CSn_PIN_NAME SPIFI_CSN                         /*!<@brief Pin name */
#define BOARD_SPIFI_CSn_LABEL "J13[8]/U27[1]/P0_23-SPIFI_CSn-MCLK" /*!<@brief Label */
#define BOARD_SPIFI_CSn_NAME "SPIFI_CSn"                           /*!<@brief Identifier name */
                                                                   /* @} */

/*! @name PIO2_12 (coord M2), U26A1[3]/P2_12-SPIFI_RSTn
  @{ */
#define BOARD_SPIFI_RSTn_PERIPHERAL GPIO                   /*!<@brief Device name: GPIO */
#define BOARD_SPIFI_RSTn_SIGNAL PIO2                       /*!<@brief GPIO signal: PIO2 */
#define BOARD_SPIFI_RSTn_GPIO GPIO                         /*!<@brief GPIO device name: GPIO */
#define BOARD_SPIFI_RSTn_GPIO_PIN 12U                      /*!<@brief PIO2 pin index: 12 */
#define BOARD_SPIFI_RSTn_PORT 2U                           /*!<@brief PORT device name: 2U */
#define BOARD_SPIFI_RSTn_PIN 12U                           /*!<@brief 2U pin index: 12 */
#define BOARD_SPIFI_RSTn_CHANNEL 12                        /*!<@brief GPIO PIO2 channel: 12 */
#define BOARD_SPIFI_RSTn_PIN_NAME PIO2_12                  /*!<@brief Pin name */
#define BOARD_SPIFI_RSTn_LABEL "U26A1[3]/P2_12-SPIFI_RSTn" /*!<@brief Label */
#define BOARD_SPIFI_RSTn_NAME "SPIFI_RSTn"                 /*!<@brief Identifier name */
                                                           /* @} */

/*!
 * @brief Configures pin routing and optionally pin electrical features.
 *
 */
void BOARD_InitQSPI_FLASH(void); /* Function assigned for the Cortex-M4F */

#define PIO210_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO210_FUNC_ALT2 0x02u        /*!<@brief Selects pin function.: Alternative connection 2. */
#define PIO23_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO23_FUNC_ALT2 0x02u         /*!<@brief Selects pin function.: Alternative connection 2. */
#define PIO24_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO24_FUNC_ALT2 0x02u         /*!<@brief Selects pin function.: Alternative connection 2. */
#define PIO25_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO25_FUNC_ALT2 0x02u         /*!<@brief Selects pin function.: Alternative connection 2. */
#define PIO26_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO26_FUNC_ALT2 0x02u         /*!<@brief Selects pin function.: Alternative connection 2. */
#define PIO27_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO27_FUNC_ALT2 0x02u         /*!<@brief Selects pin function.: Alternative connection 2. */
#define PIO28_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO28_FUNC_ALT2 0x02u         /*!<@brief Selects pin function.: Alternative connection 2. */
#define PIO29_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO29_FUNC_ALT2 0x02u         /*!<@brief Selects pin function.: Alternative connection 2. */
#define PIO315_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO315_FUNC_ALT2 0x02u        /*!<@brief Selects pin function.: Alternative connection 2. */

/*! @name SD_WR_PRT (coord D2), RP1[1]/U9[8]/P3_15-SD_WPn
  @{ */
#define BOARD_SD_WPn_PERIPHERAL SDIF                   /*!<@brief Device name: SDIF */
#define BOARD_SD_WPn_SIGNAL SD_WR_PRT                  /*!<@brief SDIF signal: SD_WR_PRT */
#define BOARD_SD_WPn_PIN_NAME SD_WR_PRT                /*!<@brief Pin name */
#define BOARD_SD_WPn_LABEL "RP1[1]/U9[8]/P3_15-SD_WPn" /*!<@brief Label */
#define BOARD_SD_WPn_NAME "SD_WPn"                     /*!<@brief Identifier name */
                                                       /* @} */

/*! @name SD_CARD_DET_N (coord P1), RP1[2]/U9[7]/P2_10-SD_CDn
  @{ */
#define BOARD_SD_CDn_PERIPHERAL SDIF                   /*!<@brief Device name: SDIF */
#define BOARD_SD_CDn_SIGNAL SD_CARD_DET                /*!<@brief SDIF signal: SD_CARD_DET */
#define BOARD_SD_CDn_PIN_NAME SD_CARD_DET_N            /*!<@brief Pin name */
#define BOARD_SD_CDn_LABEL "RP1[2]/U9[7]/P2_10-SD_CDn" /*!<@brief Label */
#define BOARD_SD_CDn_NAME "SD_CDn"                     /*!<@brief Identifier name */
                                                       /* @} */

/*! @name SD_D(2) (coord F4), RP1[3]/U9[6]/P2_8-SD_D2
  @{ */
#define BOARD_SD_D2_PERIPHERAL SDIF                 /*!<@brief Device name: SDIF */
#define BOARD_SD_D2_SIGNAL SD_D                     /*!<@brief SDIF signal: SD_D */
#define BOARD_SD_D2_CHANNEL 2                       /*!<@brief SDIF SD_D channel: 2 */
#define BOARD_SD_D2_PIN_NAME SD_D(2)                /*!<@brief Pin name */
#define BOARD_SD_D2_LABEL "RP1[3]/U9[6]/P2_8-SD_D2" /*!<@brief Label */
#define BOARD_SD_D2_NAME "SD_D2"                    /*!<@brief Identifier name */
                                                    /* @} */

/*! @name SD_D(1) (coord J2), RP1[4]/U9[5]/P2_7-SD_D1
  @{ */
#define BOARD_SD_D1_PERIPHERAL SDIF                 /*!<@brief Device name: SDIF */
#define BOARD_SD_D1_SIGNAL SD_D                     /*!<@brief SDIF signal: SD_D */
#define BOARD_SD_D1_CHANNEL 1                       /*!<@brief SDIF SD_D channel: 1 */
#define BOARD_SD_D1_PIN_NAME SD_D(1)                /*!<@brief Pin name */
#define BOARD_SD_D1_LABEL "RP1[4]/U9[5]/P2_7-SD_D1" /*!<@brief Label */
#define BOARD_SD_D1_NAME "SD_D1"                    /*!<@brief Identifier name */
                                                    /* @} */

/*! @name SD_D(0) (coord F3), RP1[5]/U9[4]/P2_6-SD_D0
  @{ */
#define BOARD_SD_D0_PERIPHERAL SDIF                 /*!<@brief Device name: SDIF */
#define BOARD_SD_D0_SIGNAL SD_D                     /*!<@brief SDIF signal: SD_D */
#define BOARD_SD_D0_CHANNEL 0                       /*!<@brief SDIF SD_D channel: 0 */
#define BOARD_SD_D0_PIN_NAME SD_D(0)                /*!<@brief Pin name */
#define BOARD_SD_D0_LABEL "RP1[5]/U9[4]/P2_6-SD_D0" /*!<@brief Label */
#define BOARD_SD_D0_NAME "SD_D0"                    /*!<@brief Identifier name */
                                                    /* @} */

/*! @name SD_CLK (coord B1), U9[3]/P2_3-SD_CLK
  @{ */
#define BOARD_SD_CLK_PERIPHERAL SDIF           /*!<@brief Device name: SDIF */
#define BOARD_SD_CLK_SIGNAL SD_CLK             /*!<@brief SDIF signal: SD_CLK */
#define BOARD_SD_CLK_PIN_NAME SD_CLK           /*!<@brief Pin name */
#define BOARD_SD_CLK_LABEL "U9[3]/P2_3-SD_CLK" /*!<@brief Label */
#define BOARD_SD_CLK_NAME "SD_CLK"             /*!<@brief Identifier name */
                                               /* @} */

/*! @name SD_CMD (coord D3), RP1[6]/U9[2]/P2_4-SD_CMD
  @{ */
#define BOARD_SD_CMD_PERIPHERAL SDIF                  /*!<@brief Device name: SDIF */
#define BOARD_SD_CMD_SIGNAL SD_CMD                    /*!<@brief SDIF signal: SD_CMD */
#define BOARD_SD_CMD_PIN_NAME SD_CMD                  /*!<@brief Pin name */
#define BOARD_SD_CMD_LABEL "RP1[6]/U9[2]/P2_4-SD_CMD" /*!<@brief Label */
#define BOARD_SD_CMD_NAME "SD_CMD"                    /*!<@brief Identifier name */
                                                      /* @} */

/*! @name SD_D(3) (coord K2), RP1[7]/U9[1]/P2_9-SD_D3
  @{ */
#define BOARD_SD_D3_PERIPHERAL SDIF                 /*!<@brief Device name: SDIF */
#define BOARD_SD_D3_SIGNAL SD_D                     /*!<@brief SDIF signal: SD_D */
#define BOARD_SD_D3_CHANNEL 3                       /*!<@brief SDIF SD_D channel: 3 */
#define BOARD_SD_D3_PIN_NAME SD_D(3)                /*!<@brief Pin name */
#define BOARD_SD_D3_LABEL "RP1[7]/U9[1]/P2_9-SD_D3" /*!<@brief Label */
#define BOARD_SD_D3_NAME "SD_D3"                    /*!<@brief Identifier name */
                                                    /* @} */

/*! @name SD_POW_EN (coord C1), Q3[1]/P2_5-SD_POW_EN
  @{ */
#define BOARD_SD_POW_EN_PERIPHERAL SDIF              /*!<@brief Device name: SDIF */
#define BOARD_SD_POW_EN_SIGNAL SD_POW_EN             /*!<@brief SDIF signal: SD_POW_EN */
#define BOARD_SD_POW_EN_PIN_NAME SD_POW_EN           /*!<@brief Pin name */
#define BOARD_SD_POW_EN_LABEL "Q3[1]/P2_5-SD_POW_EN" /*!<@brief Label */
#define BOARD_SD_POW_EN_NAME "SD_POW_EN"             /*!<@brief Identifier name */
                                                     /* @} */

/*!
 * @brief Configures pin routing and optionally pin electrical features.
 *
 */
void BOARD_InitSDHC(void); /* Function assigned for the Cortex-M4F */

#define PIO022_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO022_FUNC_ALT7 0x07u        /*!<@brief Selects pin function.: Alternative connection 7. */
#define PIO411_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO411_FUNC_ALT3 0x03u        /*!<@brief Selects pin function.: Alternative connection 3. */

/*! @name USB1_DP (coord H3), J2[3]/U2[2]/U25[H3]/USB1_DP_TRGT
  @{ */
#define BOARD_USB1_DP_PERIPHERAL USBHSH                        /*!<@brief Device name: USBHSH */
#define BOARD_USB1_DP_SIGNAL USB_DP                            /*!<@brief USBHSH signal: USB_DP */
#define BOARD_USB1_DP_PIN_NAME USB1_DP                         /*!<@brief Pin name */
#define BOARD_USB1_DP_LABEL "J2[3]/U2[2]/U25[H3]/USB1_DP_TRGT" /*!<@brief Label */
#define BOARD_USB1_DP_NAME "USB1_DP"                           /*!<@brief Identifier name */
                                                               /* @} */

/*! @name USB1_DM (coord H2), J2[2]/U2[3]/U25[H2]/USB1_DM_TRGT
  @{ */
#define BOARD_USB1_DM_PERIPHERAL USBHSH                        /*!<@brief Device name: USBHSH */
#define BOARD_USB1_DM_SIGNAL USB_DM                            /*!<@brief USBHSH signal: USB_DM */
#define BOARD_USB1_DM_PIN_NAME USB1_DM                         /*!<@brief Pin name */
#define BOARD_USB1_DM_LABEL "J2[2]/U2[3]/U25[H2]/USB1_DM_TRGT" /*!<@brief Label */
#define BOARD_USB1_DM_NAME "USB1_DM"                           /*!<@brief Identifier name */
                                                               /* @} */

/*! @name USB0_DM (coord D5), J3[2]/U3[3]/USB0_DM_TRGT
  @{ */
#define BOARD_USB0_DM_PERIPHERAL USBFSH                /*!<@brief Device name: USBFSH */
#define BOARD_USB0_DM_SIGNAL USB_DM                    /*!<@brief USBFSH signal: USB_DM */
#define BOARD_USB0_DM_PIN_NAME USB0_DM                 /*!<@brief Pin name */
#define BOARD_USB0_DM_LABEL "J3[2]/U3[3]/USB0_DM_TRGT" /*!<@brief Label */
#define BOARD_USB0_DM_NAME "USB0_DM"                   /*!<@brief Identifier name */
                                                       /* @} */

/*! @name USB0_DP (coord E5), J3[3]/U3[2]/USB0_DP_TRGT
  @{ */
#define BOARD_USB0_DP_PERIPHERAL USBFSH                /*!<@brief Device name: USBFSH */
#define BOARD_USB0_DP_SIGNAL USB_DP                    /*!<@brief USBFSH signal: USB_DP */
#define BOARD_USB0_DP_PIN_NAME USB0_DP                 /*!<@brief Pin name */
#define BOARD_USB0_DP_LABEL "J3[3]/U3[2]/USB0_DP_TRGT" /*!<@brief Label */
#define BOARD_USB0_DP_NAME "USB0_DP"                   /*!<@brief Identifier name */
                                                       /* @} */

/*! @name USB1_VBUS (coord G2), J2[1]/U2[4]/VBUS1_TARGET
  @{ */
#define BOARD_USB1_VBUS_PERIPHERAL USBHSH                /*!<@brief Device name: USBHSH */
#define BOARD_USB1_VBUS_SIGNAL USB_VBUS                  /*!<@brief USBHSH signal: USB_VBUS */
#define BOARD_USB1_VBUS_PIN_NAME USB1_VBUS               /*!<@brief Pin name */
#define BOARD_USB1_VBUS_LABEL "J2[1]/U2[4]/VBUS1_TARGET" /*!<@brief Label */
#define BOARD_USB1_VBUS_NAME "USB1_VBUS"                 /*!<@brief Identifier name */
                                                         /* @} */

/*! @name USB0_VBUS (coord B12), U3[4]/J3[1]/P0_22-USB0_VBUS
  @{ */
#define BOARD_USB0_VBUS_PERIPHERAL USBFSH                   /*!<@brief Device name: USBFSH */
#define BOARD_USB0_VBUS_SIGNAL USB_VBUS                     /*!<@brief USBFSH signal: USB_VBUS */
#define BOARD_USB0_VBUS_PIN_NAME USB0_VBUS                  /*!<@brief Pin name */
#define BOARD_USB0_VBUS_LABEL "U3[4]/J3[1]/P0_22-USB0_VBUS" /*!<@brief Label */
#define BOARD_USB0_VBUS_NAME "USB0_VBUS"                    /*!<@brief Identifier name */
                                                            /* @} */

/*! @name USB1_ID (coord G1), J2[4]/USB1_ID_TARGET
  @{ */
#define BOARD_USB1_ID_PERIPHERAL USBHSH            /*!<@brief Device name: USBHSH */
#define BOARD_USB1_ID_SIGNAL USB_IDVALUE           /*!<@brief USBHSH signal: USB_IDVALUE */
#define BOARD_USB1_ID_PIN_NAME USB1_ID             /*!<@brief Pin name */
#define BOARD_USB1_ID_LABEL "J2[4]/USB1_ID_TARGET" /*!<@brief Label */
#define BOARD_USB1_ID_NAME "USB1_ID"               /*!<@brief Identifier name */
                                                   /* @} */

/*! @name USB0_IDVALUE (coord A9), U12[8]/JP12[1]/J3[4]/JP12[3]/P4_11-USB0_ID/P4_11-ENET_RXD0
  @{ */
/*!
 * @brief Device name: USBFSH */
#define BOARD_ENET_RXD0_PERIPHERAL USBFSH
/*!
 * @brief USBFSH signal: USB_IDVALUE */
#define BOARD_ENET_RXD0_SIGNAL USB_IDVALUE
/*!
 * @brief Pin name */
#define BOARD_ENET_RXD0_PIN_NAME USB0_IDVALUE
/*!
 * @brief Label */
#define BOARD_ENET_RXD0_LABEL "U12[8]/JP12[1]/J3[4]/JP12[3]/P4_11-USB0_ID/P4_11-ENET_RXD0"
/*!
 * @brief Identifier name */
#define BOARD_ENET_RXD0_NAME "ENET_RXD0"
/* @} */

/*!
 * @brief Configures pin routing and optionally pin electrical features.
 *
 */
void BOARD_InitUSB(void); /* Function assigned for the Cortex-M4F */

#define PIO029_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO029_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO030_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO030_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */

/*! @name FC0_RXD_SDA_MOSI (coord B13), U24[13]/P0_29-ISP_FC0_RXD
  @{ */
#define BOARD_ISP_FC0_RXD_PERIPHERAL FLEXCOMM0              /*!<@brief Device name: FLEXCOMM0 */
#define BOARD_ISP_FC0_RXD_SIGNAL RXD_SDA_MOSI               /*!<@brief FLEXCOMM0 signal: RXD_SDA_MOSI */
#define BOARD_ISP_FC0_RXD_PIN_NAME FC0_RXD_SDA_MOSI         /*!<@brief Pin name */
#define BOARD_ISP_FC0_RXD_LABEL "U24[13]/P0_29-ISP_FC0_RXD" /*!<@brief Label */
#define BOARD_ISP_FC0_RXD_NAME "ISP_FC0_RXD"                /*!<@brief Identifier name */
#define BOARD_ISP_FC0_RXD_DIRECTION kPIN_MUX_DirectionInput /*!<@brief Direction */
                                                            /* @} */

/*! @name FC0_TXD_SCL_MISO (coord A2), U24[12]/P0_30-ISP_FC0_TXD
  @{ */
#define BOARD_ISP_FC0_TXD_PERIPHERAL FLEXCOMM0               /*!<@brief Device name: FLEXCOMM0 */
#define BOARD_ISP_FC0_TXD_SIGNAL TXD_SCL_MISO                /*!<@brief FLEXCOMM0 signal: TXD_SCL_MISO */
#define BOARD_ISP_FC0_TXD_PIN_NAME FC0_TXD_SCL_MISO          /*!<@brief Pin name */
#define BOARD_ISP_FC0_TXD_LABEL "U24[12]/P0_30-ISP_FC0_TXD"  /*!<@brief Label */
#define BOARD_ISP_FC0_TXD_NAME "ISP_FC0_TXD"                 /*!<@brief Identifier name */
#define BOARD_ISP_FC0_TXD_DIRECTION kPIN_MUX_DirectionOutput /*!<@brief Direction */
                                                             /* @} */

/*!
 * @brief Configures pin routing and optionally pin electrical features.
 *
 */
void BOARD_InitDEBUG_UART(void); /* Function assigned for the Cortex-M4F */

#define PIO010_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO010_FUNC_ALT6 0x06u        /*!<@brief Selects pin function.: Alternative connection 6. */
#define PIO011_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO011_FUNC_ALT6 0x06u        /*!<@brief Selects pin function.: Alternative connection 6. */
#define PIO012_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO012_FUNC_ALT6 0x06u        /*!<@brief Selects pin function.: Alternative connection 6. */

/*! @name SWDIO (coord M3), P1[2]/U22[4]/D5[5]/IF_SWDIO
  @{ */
#define BOARD_IF_SWDIO_PERIPHERAL SWD                      /*!<@brief Device name: SWD */
#define BOARD_IF_SWDIO_SIGNAL SWDIO                        /*!<@brief SWD signal: SWDIO */
#define BOARD_IF_SWDIO_PIN_NAME SWDIO                      /*!<@brief Pin name */
#define BOARD_IF_SWDIO_LABEL "P1[2]/U22[4]/D5[5]/IF_SWDIO" /*!<@brief Label */
#define BOARD_IF_SWDIO_NAME "IF_SWDIO"                     /*!<@brief Identifier name */
                                                           /* @} */

/*! @name SWCLK (coord L3), U16[4]/SWDCLK_TRGT
  @{ */
#define BOARD_SWDCLK_TRGT_PERIPHERAL SWD             /*!<@brief Device name: SWD */
#define BOARD_SWDCLK_TRGT_SIGNAL SWCLK               /*!<@brief SWD signal: SWCLK */
#define BOARD_SWDCLK_TRGT_PIN_NAME SWCLK             /*!<@brief Pin name */
#define BOARD_SWDCLK_TRGT_LABEL "U16[4]/SWDCLK_TRGT" /*!<@brief Label */
#define BOARD_SWDCLK_TRGT_NAME "SWDCLK_TRGT"         /*!<@brief Identifier name */
                                                     /* @} */

/*! @name SWO (coord P2), U16[12]/SWO_TRGT
  @{ */
#define BOARD_SWO_TRGT_PERIPHERAL SWD           /*!<@brief Device name: SWD */
#define BOARD_SWO_TRGT_SIGNAL SWO               /*!<@brief SWD signal: SWO */
#define BOARD_SWO_TRGT_PIN_NAME SWO             /*!<@brief Pin name */
#define BOARD_SWO_TRGT_LABEL "U16[12]/SWO_TRGT" /*!<@brief Label */
#define BOARD_SWO_TRGT_NAME "SWO_TRGT"          /*!<@brief Identifier name */
                                                /* @} */

/*!
 * @brief Configures pin routing and optionally pin electrical features.
 *
 */
void BOARD_InitSWD_DEBUG(void); /* Function assigned for the Cortex-M4F */

#define PIO211_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO211_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO213_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO213_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO214_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO214_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO215_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO215_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO216_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO216_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO221_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO221_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO222_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO222_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO223_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO223_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO224_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO224_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO225_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO225_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO228_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO228_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO229_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO229_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO230_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO230_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO231_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO231_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO30_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO30_FUNC_ALT1 0x01u         /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO31_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO31_FUNC_ALT1 0x01u         /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO35_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO35_FUNC_ALT1 0x01u         /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO36_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO36_FUNC_ALT1 0x01u         /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO37_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO37_FUNC_ALT1 0x01u         /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO38_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO38_FUNC_ALT1 0x01u         /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO39_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO39_FUNC_ALT1 0x01u         /*!<@brief Selects pin function.: Alternative connection 1. */

/*! @name LCD_PWR (coord K3), J16[31]/P2_11-LCD_PWR
  @{ */
#define BOARD_LCD_PWR_PERIPHERAL LCD                /*!<@brief Device name: LCD */
#define BOARD_LCD_PWR_SIGNAL LCD_PWR                /*!<@brief LCD signal: LCD_PWR */
#define BOARD_LCD_PWR_PIN_NAME LCD_PWR              /*!<@brief Pin name */
#define BOARD_LCD_PWR_LABEL "J16[31]/P2_11-LCD_PWR" /*!<@brief Label */
#define BOARD_LCD_PWR_NAME "LCD_PWR"                /*!<@brief Identifier name */
                                                    /* @} */

/*! @name LCD_FP (coord L7), J16[33]/P2_14-LCD_FP
  @{ */
#define BOARD_LCD_FP_PERIPHERAL LCD               /*!<@brief Device name: LCD */
#define BOARD_LCD_FP_SIGNAL LCD_FP                /*!<@brief LCD signal: LCD_FP */
#define BOARD_LCD_FP_PIN_NAME LCD_FP              /*!<@brief Pin name */
#define BOARD_LCD_FP_LABEL "J16[33]/P2_14-LCD_FP" /*!<@brief Label */
#define BOARD_LCD_FP_NAME "LCD_FP"                /*!<@brief Identifier name */
                                                  /* @} */

/*! @name LCD_DCLK (coord P7), J16[30]/P2_13-LCD_DCLK
  @{ */
#define BOARD_LCD_DCLK_PERIPHERAL LCD                 /*!<@brief Device name: LCD */
#define BOARD_LCD_DCLK_SIGNAL LCD_DCLK                /*!<@brief LCD signal: LCD_DCLK */
#define BOARD_LCD_DCLK_PIN_NAME LCD_DCLK              /*!<@brief Pin name */
#define BOARD_LCD_DCLK_LABEL "J16[30]/P2_13-LCD_DCLK" /*!<@brief Label */
#define BOARD_LCD_DCLK_NAME "LCD_DCLK"                /*!<@brief Identifier name */
                                                      /* @} */

/*! @name LCD_LP (coord L8), J16[32]/P2_16-LCD_LP
  @{ */
#define BOARD_LCD_LP_PERIPHERAL LCD               /*!<@brief Device name: LCD */
#define BOARD_LCD_LP_SIGNAL LCD_LP                /*!<@brief LCD signal: LCD_LP */
#define BOARD_LCD_LP_PIN_NAME LCD_LP              /*!<@brief Pin name */
#define BOARD_LCD_LP_LABEL "J16[32]/P2_16-LCD_LP" /*!<@brief Label */
#define BOARD_LCD_LP_NAME "LCD_LP"                /*!<@brief Identifier name */
                                                  /* @} */

/*! @name LCD_AC (coord M8), J16[34]/P2_15-LCD_AC_ENAB_M
  @{ */
#define BOARD_LCD_AC_ENAB_M_PERIPHERAL LCD                      /*!<@brief Device name: LCD */
#define BOARD_LCD_AC_ENAB_M_SIGNAL LCD_AC                       /*!<@brief LCD signal: LCD_AC */
#define BOARD_LCD_AC_ENAB_M_PIN_NAME LCD_AC                     /*!<@brief Pin name */
#define BOARD_LCD_AC_ENAB_M_LABEL "J16[34]/P2_15-LCD_AC_ENAB_M" /*!<@brief Label */
#define BOARD_LCD_AC_ENAB_M_NAME "LCD_AC_ENAB_M"                /*!<@brief Identifier name */
                                                                /* @} */

/*! @name LCD_VD(4) (coord K10), J16[9]/P2_22-LCD_VD4
  @{ */
#define BOARD_LCD_VD4_PERIPHERAL LCD               /*!<@brief Device name: LCD */
#define BOARD_LCD_VD4_SIGNAL LCD_VD                /*!<@brief LCD signal: LCD_VD */
#define BOARD_LCD_VD4_CHANNEL 4                    /*!<@brief LCD LCD_VD channel: 4 */
#define BOARD_LCD_VD4_PIN_NAME LCD_VD(4)           /*!<@brief Pin name */
#define BOARD_LCD_VD4_LABEL "J16[9]/P2_22-LCD_VD4" /*!<@brief Label */
#define BOARD_LCD_VD4_NAME "LCD_VD4"               /*!<@brief Identifier name */
                                                   /* @} */

/*! @name LCD_VD(3) (coord L10), J16[8]/P2_21-LCD_VD3
  @{ */
#define BOARD_LCD_VD3_PERIPHERAL LCD               /*!<@brief Device name: LCD */
#define BOARD_LCD_VD3_SIGNAL LCD_VD                /*!<@brief LCD signal: LCD_VD */
#define BOARD_LCD_VD3_CHANNEL 3                    /*!<@brief LCD LCD_VD channel: 3 */
#define BOARD_LCD_VD3_PIN_NAME LCD_VD(3)           /*!<@brief Pin name */
#define BOARD_LCD_VD3_LABEL "J16[8]/P2_21-LCD_VD3" /*!<@brief Label */
#define BOARD_LCD_VD3_NAME "LCD_VD3"               /*!<@brief Identifier name */
                                                   /* @} */

/*! @name LCD_VD(11) (coord G11), J16[16]/P2_29-LCD_VD11
  @{ */
#define BOARD_LCD_VD11_PERIPHERAL LCD                 /*!<@brief Device name: LCD */
#define BOARD_LCD_VD11_SIGNAL LCD_VD                  /*!<@brief LCD signal: LCD_VD */
#define BOARD_LCD_VD11_CHANNEL 11                     /*!<@brief LCD LCD_VD channel: 11 */
#define BOARD_LCD_VD11_PIN_NAME LCD_VD(11)            /*!<@brief Pin name */
#define BOARD_LCD_VD11_LABEL "J16[16]/P2_29-LCD_VD11" /*!<@brief Label */
#define BOARD_LCD_VD11_NAME "LCD_VD11"                /*!<@brief Identifier name */
                                                      /* @} */

/*! @name LCD_VD(7) (coord J11), J16[12]/P2_25-LCD_VD7
  @{ */
#define BOARD_LCD_VD7_PERIPHERAL LCD                /*!<@brief Device name: LCD */
#define BOARD_LCD_VD7_SIGNAL LCD_VD                 /*!<@brief LCD signal: LCD_VD */
#define BOARD_LCD_VD7_CHANNEL 7                     /*!<@brief LCD LCD_VD channel: 7 */
#define BOARD_LCD_VD7_PIN_NAME LCD_VD(7)            /*!<@brief Pin name */
#define BOARD_LCD_VD7_LABEL "J16[12]/P2_25-LCD_VD7" /*!<@brief Label */
#define BOARD_LCD_VD7_NAME "LCD_VD7"                /*!<@brief Identifier name */
                                                    /* @} */

/*! @name LCD_VD(12) (coord F12), J16[17]/P2_30-LCD_VD12
  @{ */
#define BOARD_LCD_VD12_PERIPHERAL LCD                 /*!<@brief Device name: LCD */
#define BOARD_LCD_VD12_SIGNAL LCD_VD                  /*!<@brief LCD signal: LCD_VD */
#define BOARD_LCD_VD12_CHANNEL 12                     /*!<@brief LCD LCD_VD channel: 12 */
#define BOARD_LCD_VD12_PIN_NAME LCD_VD(12)            /*!<@brief Pin name */
#define BOARD_LCD_VD12_LABEL "J16[17]/P2_30-LCD_VD12" /*!<@brief Label */
#define BOARD_LCD_VD12_NAME "LCD_VD12"                /*!<@brief Identifier name */
                                                      /* @} */

/*! @name LCD_VD(10) (coord G13), J16[15]/P2_28-LCD_VD10
  @{ */
#define BOARD_LCD_VD10_PERIPHERAL LCD                 /*!<@brief Device name: LCD */
#define BOARD_LCD_VD10_SIGNAL LCD_VD                  /*!<@brief LCD signal: LCD_VD */
#define BOARD_LCD_VD10_CHANNEL 10                     /*!<@brief LCD LCD_VD channel: 10 */
#define BOARD_LCD_VD10_PIN_NAME LCD_VD(10)            /*!<@brief Pin name */
#define BOARD_LCD_VD10_LABEL "J16[15]/P2_28-LCD_VD10" /*!<@brief Label */
#define BOARD_LCD_VD10_NAME "LCD_VD10"                /*!<@brief Identifier name */
                                                      /* @} */

/*! @name LCD_VD(13) (coord D14), J16[18]/P2_31-LCD_VD13
  @{ */
#define BOARD_LCD_VD13_PERIPHERAL LCD                 /*!<@brief Device name: LCD */
#define BOARD_LCD_VD13_SIGNAL LCD_VD                  /*!<@brief LCD signal: LCD_VD */
#define BOARD_LCD_VD13_CHANNEL 13                     /*!<@brief LCD LCD_VD channel: 13 */
#define BOARD_LCD_VD13_PIN_NAME LCD_VD(13)            /*!<@brief Pin name */
#define BOARD_LCD_VD13_LABEL "J16[18]/P2_31-LCD_VD13" /*!<@brief Label */
#define BOARD_LCD_VD13_NAME "LCD_VD13"                /*!<@brief Identifier name */
                                                      /* @} */

/*! @name LCD_VD(6) (coord K14), J16[11]/P2_24-LCD_VD6
  @{ */
#define BOARD_LCD_VD6_PERIPHERAL LCD                /*!<@brief Device name: LCD */
#define BOARD_LCD_VD6_SIGNAL LCD_VD                 /*!<@brief LCD signal: LCD_VD */
#define BOARD_LCD_VD6_CHANNEL 6                     /*!<@brief LCD LCD_VD channel: 6 */
#define BOARD_LCD_VD6_PIN_NAME LCD_VD(6)            /*!<@brief Pin name */
#define BOARD_LCD_VD6_LABEL "J16[11]/P2_24-LCD_VD6" /*!<@brief Label */
#define BOARD_LCD_VD6_NAME "LCD_VD6"                /*!<@brief Identifier name */
                                                    /* @} */

/*! @name LCD_VD(5) (coord M14), J16[10]/P2_23-LCD_VD5
  @{ */
#define BOARD_LCD_VD5_PERIPHERAL LCD                /*!<@brief Device name: LCD */
#define BOARD_LCD_VD5_SIGNAL LCD_VD                 /*!<@brief LCD signal: LCD_VD */
#define BOARD_LCD_VD5_CHANNEL 5                     /*!<@brief LCD LCD_VD channel: 5 */
#define BOARD_LCD_VD5_PIN_NAME LCD_VD(5)            /*!<@brief Pin name */
#define BOARD_LCD_VD5_LABEL "J16[10]/P2_23-LCD_VD5" /*!<@brief Label */
#define BOARD_LCD_VD5_NAME "LCD_VD5"                /*!<@brief Identifier name */
                                                    /* @} */

/*! @name LCD_VD(14) (coord D12), J16[19]/JS36[1]/P3_0-LCD_VD14
  @{ */
#define BOARD_LCD_VD14_PERIPHERAL LCD                        /*!<@brief Device name: LCD */
#define BOARD_LCD_VD14_SIGNAL LCD_VD                         /*!<@brief LCD signal: LCD_VD */
#define BOARD_LCD_VD14_CHANNEL 14                            /*!<@brief LCD LCD_VD channel: 14 */
#define BOARD_LCD_VD14_PIN_NAME LCD_VD(14)                   /*!<@brief Pin name */
#define BOARD_LCD_VD14_LABEL "J16[19]/JS36[1]/P3_0-LCD_VD14" /*!<@brief Label */
#define BOARD_LCD_VD14_NAME "LCD_VD14"                       /*!<@brief Identifier name */
                                                             /* @} */

/*! @name LCD_VD(15) (coord D11), J16[20]/JS33[1]/P3_1-LCD_VD15
  @{ */
#define BOARD_LCD_VD15_PERIPHERAL LCD                        /*!<@brief Device name: LCD */
#define BOARD_LCD_VD15_SIGNAL LCD_VD                         /*!<@brief LCD signal: LCD_VD */
#define BOARD_LCD_VD15_CHANNEL 15                            /*!<@brief LCD LCD_VD channel: 15 */
#define BOARD_LCD_VD15_PIN_NAME LCD_VD(15)                   /*!<@brief Pin name */
#define BOARD_LCD_VD15_LABEL "J16[20]/JS33[1]/P3_1-LCD_VD15" /*!<@brief Label */
#define BOARD_LCD_VD15_NAME "LCD_VD15"                       /*!<@brief Identifier name */
                                                             /* @} */

/*! @name LCD_VD(19) (coord B10), J16[24]/P3_5-LCD_VD19
  @{ */
#define BOARD_LCD_VD19_PERIPHERAL LCD                /*!<@brief Device name: LCD */
#define BOARD_LCD_VD19_SIGNAL LCD_VD                 /*!<@brief LCD signal: LCD_VD */
#define BOARD_LCD_VD19_CHANNEL 19                    /*!<@brief LCD LCD_VD channel: 19 */
#define BOARD_LCD_VD19_PIN_NAME LCD_VD(19)           /*!<@brief Pin name */
#define BOARD_LCD_VD19_LABEL "J16[24]/P3_5-LCD_VD19" /*!<@brief Label */
#define BOARD_LCD_VD19_NAME "LCD_VD19"               /*!<@brief Identifier name */
                                                     /* @} */

/*! @name LCD_VD(20) (coord C9), J16[25]/P3_6-LCD_VD20
  @{ */
#define BOARD_LCD_VD20_PERIPHERAL LCD                /*!<@brief Device name: LCD */
#define BOARD_LCD_VD20_SIGNAL LCD_VD                 /*!<@brief LCD signal: LCD_VD */
#define BOARD_LCD_VD20_CHANNEL 20                    /*!<@brief LCD LCD_VD channel: 20 */
#define BOARD_LCD_VD20_PIN_NAME LCD_VD(20)           /*!<@brief Pin name */
#define BOARD_LCD_VD20_LABEL "J16[25]/P3_6-LCD_VD20" /*!<@brief Label */
#define BOARD_LCD_VD20_NAME "LCD_VD20"               /*!<@brief Identifier name */
                                                     /* @} */

/*! @name LCD_VD(21) (coord B8), J16[26]/P3_7-LCD_VD21
  @{ */
#define BOARD_LCD_VD21_PERIPHERAL LCD                /*!<@brief Device name: LCD */
#define BOARD_LCD_VD21_SIGNAL LCD_VD                 /*!<@brief LCD signal: LCD_VD */
#define BOARD_LCD_VD21_CHANNEL 21                    /*!<@brief LCD LCD_VD channel: 21 */
#define BOARD_LCD_VD21_PIN_NAME LCD_VD(21)           /*!<@brief Pin name */
#define BOARD_LCD_VD21_LABEL "J16[26]/P3_7-LCD_VD21" /*!<@brief Label */
#define BOARD_LCD_VD21_NAME "LCD_VD21"               /*!<@brief Identifier name */
                                                     /* @} */

/*! @name LCD_VD(22) (coord A7), J16[27]/P3_8-LCD_VD22
  @{ */
#define BOARD_LCD_VD22_PERIPHERAL LCD                /*!<@brief Device name: LCD */
#define BOARD_LCD_VD22_SIGNAL LCD_VD                 /*!<@brief LCD signal: LCD_VD */
#define BOARD_LCD_VD22_CHANNEL 22                    /*!<@brief LCD LCD_VD channel: 22 */
#define BOARD_LCD_VD22_PIN_NAME LCD_VD(22)           /*!<@brief Pin name */
#define BOARD_LCD_VD22_LABEL "J16[27]/P3_8-LCD_VD22" /*!<@brief Label */
#define BOARD_LCD_VD22_NAME "LCD_VD22"               /*!<@brief Identifier name */
                                                     /* @} */

/*! @name LCD_VD(23) (coord C7), J16[28]/P3_9-LCD_VD23
  @{ */
#define BOARD_LCD_VD23_PERIPHERAL LCD                /*!<@brief Device name: LCD */
#define BOARD_LCD_VD23_SIGNAL LCD_VD                 /*!<@brief LCD signal: LCD_VD */
#define BOARD_LCD_VD23_CHANNEL 23                    /*!<@brief LCD LCD_VD channel: 23 */
#define BOARD_LCD_VD23_PIN_NAME LCD_VD(23)           /*!<@brief Pin name */
#define BOARD_LCD_VD23_LABEL "J16[28]/P3_9-LCD_VD23" /*!<@brief Label */
#define BOARD_LCD_VD23_NAME "LCD_VD23"               /*!<@brief Identifier name */
                                                     /* @} */

/*!
 * @brief Configures pin routing and optionally pin electrical features.
 *
 */
void BOARD_InitLCD(void); /* Function assigned for the Cortex-M4F */

#define PIO017_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO017_FUNC_ALT7 0x07u        /*!<@brief Selects pin function.: Alternative connection 7. */
#define PIO226_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO226_FUNC_ALT0 0x00u        /*!<@brief Selects pin function.: Alternative connection 0. */
#define PIO410_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO410_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO411_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO411_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO412_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO412_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO413_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO413_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO414_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO414_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO415_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO415_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO416_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO416_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO48_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO48_FUNC_ALT1 0x01u         /*!<@brief Selects pin function.: Alternative connection 1. */

/*! @name ENET_TXD0 (coord B14), U12[17]/JP11[1]/P4_8-ENET_TXD0
  @{ */
/*!
 * @brief Device name: ENET */
#define BOARD_INITENET_ENET_TXD0_PERIPHERAL ENET
/*!
 * @brief ENET signal: ENET_TXD */
#define BOARD_INITENET_ENET_TXD0_SIGNAL ENET_TXD
/*!
 * @brief ENET ENET_TXD channel: 0 */
#define BOARD_INITENET_ENET_TXD0_CHANNEL 0
/*!
 * @brief Pin name */
#define BOARD_INITENET_ENET_TXD0_PIN_NAME ENET_TXD0
/*!
 * @brief Label */
#define BOARD_INITENET_ENET_TXD0_LABEL "U12[17]/JP11[1]/P4_8-ENET_TXD0"
/*!
 * @brief Identifier name */
#define BOARD_INITENET_ENET_TXD0_NAME "ENET_TXD0"
/* @} */

/*! @name ENET_TXD1 (coord E14), U12[18]/P0_17-ENET_TXD1
  @{ */
#define BOARD_INITENET_ENET_TXD1_PERIPHERAL ENET                 /*!<@brief Device name: ENET */
#define BOARD_INITENET_ENET_TXD1_SIGNAL ENET_TXD                 /*!<@brief ENET signal: ENET_TXD */
#define BOARD_INITENET_ENET_TXD1_CHANNEL 1                       /*!<@brief ENET ENET_TXD channel: 1 */
#define BOARD_INITENET_ENET_TXD1_PIN_NAME ENET_TXD1              /*!<@brief Pin name */
#define BOARD_INITENET_ENET_TXD1_LABEL "U12[18]/P0_17-ENET_TXD1" /*!<@brief Label */
#define BOARD_INITENET_ENET_TXD1_NAME "ENET_TXD1"                /*!<@brief Identifier name */
                                                                 /* @} */

/*! @name ENET_TX_EN (coord B6), U12[16]/P4_13-ENET_TX_EN
  @{ */
#define BOARD_INITENET_ENET_TX_EN_PERIPHERAL ENET                  /*!<@brief Device name: ENET */
#define BOARD_INITENET_ENET_TX_EN_SIGNAL ENET_TX_EN                /*!<@brief ENET signal: ENET_TX_EN */
#define BOARD_INITENET_ENET_TX_EN_PIN_NAME ENET_TX_EN              /*!<@brief Pin name */
#define BOARD_INITENET_ENET_TX_EN_LABEL "U12[16]/P4_13-ENET_TX_EN" /*!<@brief Label */
#define BOARD_INITENET_ENET_TX_EN_NAME "ENET_TX_EN"                /*!<@brief Identifier name */
                                                                   /* @} */

/*! @name ENET_RXD0 (coord A9), U12[8]/JP12[1]/J3[4]/JP12[3]/P4_11-USB0_ID/P4_11-ENET_RXD0
  @{ */
/*!
 * @brief Device name: ENET */
#define BOARD_INITENET_ENET_RXD0_PERIPHERAL ENET
/*!
 * @brief ENET signal: ENET_RXD */
#define BOARD_INITENET_ENET_RXD0_SIGNAL ENET_RXD
/*!
 * @brief ENET ENET_RXD channel: 0 */
#define BOARD_INITENET_ENET_RXD0_CHANNEL 0
/*!
 * @brief Pin name */
#define BOARD_INITENET_ENET_RXD0_PIN_NAME ENET_RXD0
/*!
 * @brief Label */
#define BOARD_INITENET_ENET_RXD0_LABEL "U12[8]/JP12[1]/J3[4]/JP12[3]/P4_11-USB0_ID/P4_11-ENET_RXD0"
/*!
 * @brief Identifier name */
#define BOARD_INITENET_ENET_RXD0_NAME "ENET_RXD0"
/* @} */

/*! @name ENET_RXD1 (coord A6), U12[7]/P4_12-ENET_RXD1
  @{ */
#define BOARD_INITENET_ENET_RXD1_PERIPHERAL ENET                /*!<@brief Device name: ENET */
#define BOARD_INITENET_ENET_RXD1_SIGNAL ENET_RXD                /*!<@brief ENET signal: ENET_RXD */
#define BOARD_INITENET_ENET_RXD1_CHANNEL 1                      /*!<@brief ENET ENET_RXD channel: 1 */
#define BOARD_INITENET_ENET_RXD1_PIN_NAME ENET_RXD1             /*!<@brief Pin name */
#define BOARD_INITENET_ENET_RXD1_LABEL "U12[7]/P4_12-ENET_RXD1" /*!<@brief Label */
#define BOARD_INITENET_ENET_RXD1_NAME "ENET_RXD1"               /*!<@brief Identifier name */
                                                                /* @} */

/*! @name ENET_RX_DV (coord B9), U12[11]/P4_10-ENET_CRS_DV
  @{ */
#define BOARD_INITENET_ENET_CRS_DV_PERIPHERAL ENET                   /*!<@brief Device name: ENET */
#define BOARD_INITENET_ENET_CRS_DV_SIGNAL ENET_RX_DV                 /*!<@brief ENET signal: ENET_RX_DV */
#define BOARD_INITENET_ENET_CRS_DV_PIN_NAME ENET_RX_DV               /*!<@brief Pin name */
#define BOARD_INITENET_ENET_CRS_DV_LABEL "U12[11]/P4_10-ENET_CRS_DV" /*!<@brief Label */
#define BOARD_INITENET_ENET_CRS_DV_NAME "ENET_CRS_DV"                /*!<@brief Identifier name */
                                                                     /* @} */

/*! @name ENET_MDIO (coord C4), U12[12]/P4_16-ENET_MDIO
  @{ */
#define BOARD_INITENET_ENET_MDIO_PERIPHERAL ENET                 /*!<@brief Device name: ENET */
#define BOARD_INITENET_ENET_MDIO_SIGNAL ENET_MDIO                /*!<@brief ENET signal: ENET_MDIO */
#define BOARD_INITENET_ENET_MDIO_PIN_NAME ENET_MDIO              /*!<@brief Pin name */
#define BOARD_INITENET_ENET_MDIO_LABEL "U12[12]/P4_16-ENET_MDIO" /*!<@brief Label */
#define BOARD_INITENET_ENET_MDIO_NAME "ENET_MDIO"                /*!<@brief Identifier name */
                                                                 /* @} */

/*! @name ENET_MDC (coord A4), U12[13]/P4_15-ENET_MDC
  @{ */
#define BOARD_INITENET_ENET_MDC_PERIPHERAL ENET                /*!<@brief Device name: ENET */
#define BOARD_INITENET_ENET_MDC_SIGNAL ENET_MDC                /*!<@brief ENET signal: ENET_MDC */
#define BOARD_INITENET_ENET_MDC_PIN_NAME ENET_MDC              /*!<@brief Pin name */
#define BOARD_INITENET_ENET_MDC_LABEL "U12[13]/P4_15-ENET_MDC" /*!<@brief Label */
#define BOARD_INITENET_ENET_MDC_NAME "ENET_MDC"                /*!<@brief Identifier name */
                                                               /* @} */

/*! @name PIO2_26 (coord H11), U12[15]/P2_26-ENET_PHY_RSTn
  @{ */
/*!
 * @brief Device name: GPIO */
#define BOARD_INITENET_ENET_PHY_RSTn_PERIPHERAL GPIO
/*!
 * @brief GPIO signal: PIO2 */
#define BOARD_INITENET_ENET_PHY_RSTn_SIGNAL PIO2
/*!
 * @brief GPIO device name: GPIO */
#define BOARD_INITENET_ENET_PHY_RSTn_GPIO GPIO
/*!
 * @brief PIO2 pin index: 26 */
#define BOARD_INITENET_ENET_PHY_RSTn_GPIO_PIN 26U
/*!
 * @brief PORT device name: 2U */
#define BOARD_INITENET_ENET_PHY_RSTn_PORT 2U
/*!
 * @brief 2U pin index: 26 */
#define BOARD_INITENET_ENET_PHY_RSTn_PIN 26U
/*!
 * @brief GPIO PIO2 channel: 26 */
#define BOARD_INITENET_ENET_PHY_RSTn_CHANNEL 26
/*!
 * @brief Pin name */
#define BOARD_INITENET_ENET_PHY_RSTn_PIN_NAME PIO2_26
/*!
 * @brief Label */
#define BOARD_INITENET_ENET_PHY_RSTn_LABEL "U12[15]/P2_26-ENET_PHY_RSTn"
/*!
 * @brief Identifier name */
#define BOARD_INITENET_ENET_PHY_RSTn_NAME "ENET_PHY_RSTn"
/*!
 * @brief Direction */
#define BOARD_INITENET_ENET_PHY_RSTn_DIRECTION kPIN_MUX_DirectionOutput
/* @} */

/*! @name ENET_RX_CLK (coord B5), JS18[2]/P4_14-ENET_RX_CLK
  @{ */
#define BOARD_INITENET_ENET_RX_CLK_PERIPHERAL ENET                   /*!<@brief Device name: ENET */
#define BOARD_INITENET_ENET_RX_CLK_SIGNAL ENET_RX_CLK                /*!<@brief ENET signal: ENET_RX_CLK */
#define BOARD_INITENET_ENET_RX_CLK_PIN_NAME ENET_RX_CLK              /*!<@brief Pin name */
#define BOARD_INITENET_ENET_RX_CLK_LABEL "JS18[2]/P4_14-ENET_RX_CLK" /*!<@brief Label */
#define BOARD_INITENET_ENET_RX_CLK_NAME "ENET_RX_CLK"                /*!<@brief Identifier name */
                                                                     /* @} */

/*!
 * @brief Configures pin routing and optionally pin electrical features.
 *
 */
void BOARD_InitENET(void); /* Function assigned for the Cortex-M4F */

#define PIO12_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO12_FUNC_ALT5 0x05u        /*!<@brief Selects pin function.: Alternative connection 5. */
#define PIO13_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO13_FUNC_ALT5 0x05u        /*!<@brief Selects pin function.: Alternative connection 5. */

/*! @name PDM1_CLK (coord L14), J13[18]/JS25[3]/DMIC1[4]/P1_2-PDM1_CLK
  @{ */
#define BOARD_PDM1_CLK_PERIPHERAL DMIC0                               /*!<@brief Device name: DMIC0 */
#define BOARD_PDM1_CLK_SIGNAL CLK                                     /*!<@brief DMIC0 signal: CLK */
#define BOARD_PDM1_CLK_CHANNEL 1                                      /*!<@brief DMIC0 CLK channel: 1 */
#define BOARD_PDM1_CLK_PIN_NAME PDM1_CLK                              /*!<@brief Pin name */
#define BOARD_PDM1_CLK_LABEL "J13[18]/JS25[3]/DMIC1[4]/P1_2-PDM1_CLK" /*!<@brief Label */
#define BOARD_PDM1_CLK_NAME "PDM1_CLK"                                /*!<@brief Identifier name */
                                                                      /* @} */

/*! @name PDM1_DATA (coord J13), JS26[3]/DMIC1[1]/P1_3-PDM1_DATA
  @{ */
#define BOARD_PDM1_DATA_PERIPHERAL DMIC0                        /*!<@brief Device name: DMIC0 */
#define BOARD_PDM1_DATA_SIGNAL DATA                             /*!<@brief DMIC0 signal: DATA */
#define BOARD_PDM1_DATA_CHANNEL 1                               /*!<@brief DMIC0 DATA channel: 1 */
#define BOARD_PDM1_DATA_PIN_NAME PDM1_DATA                      /*!<@brief Pin name */
#define BOARD_PDM1_DATA_LABEL "JS26[3]/DMIC1[1]/P1_3-PDM1_DATA" /*!<@brief Label */
#define BOARD_PDM1_DATA_NAME "PDM1_DATA"                        /*!<@brief Identifier name */
                                                                /* @} */

/*!
 * @brief Configures pin routing and optionally pin electrical features.
 *
 */
void BOARD_InitDMIC(void); /* Function assigned for the Cortex-M4F */

#define PIO218_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO218_FUNC_ALT3 0x03u        /*!<@brief Selects pin function.: Alternative connection 3. */
#define PIO219_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO219_FUNC_ALT3 0x03u        /*!<@brief Selects pin function.: Alternative connection 3. */
#define PIO220_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO220_FUNC_ALT2 0x02u        /*!<@brief Selects pin function.: Alternative connection 2. */
#define PIO311_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO311_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO323_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO323_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO324_DIGIMODE_DIGITAL 0x01u /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO324_FUNC_ALT1 0x01u        /*!<@brief Selects pin function.: Alternative connection 1. */
#define PIO41_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO41_FUNC_ALT2 0x02u         /*!<@brief Selects pin function.: Alternative connection 2. */
#define PIO42_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO42_FUNC_ALT2 0x02u         /*!<@brief Selects pin function.: Alternative connection 2. */
#define PIO43_DIGIMODE_DIGITAL 0x01u  /*!<@brief Select Analog/Digital mode.: Digital mode. */
#define PIO43_FUNC_ALT2 0x02u         /*!<@brief Selects pin function.: Alternative connection 2. */

/*! @name FC6_SCK (coord G14), U10[29]/J9[14]/P4_1-FC6_I2S_TX_SCK
  @{ */
/*!
 * @brief Device name: FLEXCOMM6 */
#define BOARD_FC6_I2S_TX_SCK_PERIPHERAL FLEXCOMM6
/*!
 * @brief FLEXCOMM6 signal: SCK */
#define BOARD_FC6_I2S_TX_SCK_SIGNAL SCK
/*!
 * @brief Pin name */
#define BOARD_FC6_I2S_TX_SCK_PIN_NAME FC6_SCK
/*!
 * @brief Label */
#define BOARD_FC6_I2S_TX_SCK_LABEL "U10[29]/J9[14]/P4_1-FC6_I2S_TX_SCK"
/*!
 * @brief Identifier name */
#define BOARD_FC6_I2S_TX_SCK_NAME "FC6_I2S_TX_SCK"
/* @} */

/*! @name FC6_TXD_SCL_MISO_WS (coord F13), U10[30]/J9[12]/P4_3-FC6_I2S_TX_WS
  @{ */
#define BOARD_FC6_I2S_TX_WS_PERIPHERAL FLEXCOMM6                      /*!<@brief Device name: FLEXCOMM6 */
#define BOARD_FC6_I2S_TX_WS_SIGNAL TXD_SCL_MISO_WS                    /*!<@brief FLEXCOMM6 signal: TXD_SCL_MISO_WS */
#define BOARD_FC6_I2S_TX_WS_PIN_NAME FC6_TXD_SCL_MISO_WS              /*!<@brief Pin name */
#define BOARD_FC6_I2S_TX_WS_LABEL "U10[30]/J9[12]/P4_3-FC6_I2S_TX_WS" /*!<@brief Label */
#define BOARD_FC6_I2S_TX_WS_NAME "FC6_I2S_TX_WS"                      /*!<@brief Identifier name */
                                                                      /* @} */

/*! @name FC6_RXD_SDA_MOSI_DATA (coord F14), U10[32]/J9[10]/P4_2-FC6_I2S_TX_DATA
  @{ */
/*!
 * @brief Device name: FLEXCOMM6 */
#define BOARD_FC6_I2S_TX_DATA_PERIPHERAL FLEXCOMM6
/*!
 * @brief FLEXCOMM6 signal: RXD_SDA_MOSI_DATA */
#define BOARD_FC6_I2S_TX_DATA_SIGNAL RXD_SDA_MOSI_DATA
/*!
 * @brief Pin name */
#define BOARD_FC6_I2S_TX_DATA_PIN_NAME FC6_RXD_SDA_MOSI_DATA
/*!
 * @brief Label */
#define BOARD_FC6_I2S_TX_DATA_LABEL "U10[32]/J9[10]/P4_2-FC6_I2S_TX_DATA"
/*!
 * @brief Identifier name */
#define BOARD_FC6_I2S_TX_DATA_NAME "FC6_I2S_TX_DATA"
/* @} */

/*! @name FC7_RXD_SDA_MOSI_DATA (coord P12), U10[31]/J9[20]/P2_19-FC7_I2S_RX_DAT
  @{ */
/*!
 * @brief Device name: FLEXCOMM7 */
#define BOARD_FC7_I2S_RX_DAT_PERIPHERAL FLEXCOMM7
/*!
 * @brief FLEXCOMM7 signal: RXD_SDA_MOSI_DATA */
#define BOARD_FC7_I2S_RX_DAT_SIGNAL RXD_SDA_MOSI_DATA
/*!
 * @brief Pin name */
#define BOARD_FC7_I2S_RX_DAT_PIN_NAME FC7_RXD_SDA_MOSI_DATA
/*!
 * @brief Label */
#define BOARD_FC7_I2S_RX_DAT_LABEL "U10[31]/J9[20]/P2_19-FC7_I2S_RX_DAT"
/*!
 * @brief Identifier name */
#define BOARD_FC7_I2S_RX_DAT_NAME "FC7_I2S_RX_DAT"
/* @} */

/*! @name FC7_SCK (coord N10), U10[29]/J9[16]/P2_18-FC7_I2S_RX_SCK
  @{ */
/*!
 * @brief Device name: FLEXCOMM7 */
#define BOARD_FC7_I2S_RX_SCK_PERIPHERAL FLEXCOMM7
/*!
 * @brief FLEXCOMM7 signal: SCK */
#define BOARD_FC7_I2S_RX_SCK_SIGNAL SCK
/*!
 * @brief Pin name */
#define BOARD_FC7_I2S_RX_SCK_PIN_NAME FC7_SCK
/*!
 * @brief Label */
#define BOARD_FC7_I2S_RX_SCK_LABEL "U10[29]/J9[16]/P2_18-FC7_I2S_RX_SCK"
/*!
 * @brief Identifier name */
#define BOARD_FC7_I2S_RX_SCK_NAME "FC7_I2S_RX_SCK"
/* @} */

/*! @name FC3_RTS_SCL_SSEL1 (coord P13), U10[30]/J9[18]/P2_20-FC7_I2S_RX_WS
  @{ */
#define BOARD_FC7_I2S_RX_WS_PERIPHERAL FLEXCOMM3                       /*!<@brief Device name: FLEXCOMM3 */
#define BOARD_FC7_I2S_RX_WS_SIGNAL RTS_SCL_SSEL1                       /*!<@brief FLEXCOMM3 signal: RTS_SCL_SSEL1 */
#define BOARD_FC7_I2S_RX_WS_PIN_NAME FC3_RTS_SCL_SSEL1                 /*!<@brief Pin name */
#define BOARD_FC7_I2S_RX_WS_LABEL "U10[30]/J9[18]/P2_20-FC7_I2S_RX_WS" /*!<@brief Label */
#define BOARD_FC7_I2S_RX_WS_NAME "FC7_I2S_RX_WS"                       /*!<@brief Identifier name */
                                                                       /* @} */

/*! @name MCLK (coord B2), J11[8]/J12[7]/P3_11-MCLK-PMOD2_GPIO
  @{ */
#define BOARD_MCLK_PERIPHERAL SYSCON                           /*!<@brief Device name: SYSCON */
#define BOARD_MCLK_SIGNAL MCLK                                 /*!<@brief SYSCON signal: MCLK */
#define BOARD_MCLK_PIN_NAME MCLK                               /*!<@brief Pin name */
#define BOARD_MCLK_LABEL "J11[8]/J12[7]/P3_11-MCLK-PMOD2_GPIO" /*!<@brief Label */
#define BOARD_MCLK_NAME "MCLK"                                 /*!<@brief Identifier name */
                                                               /* @} */

/*!
 * @brief Configures pin routing and optionally pin electrical features.
 *
 */
void BOARD_InitI2S(void); /* Function assigned for the Cortex-M4F */

/*!
 * @brief Select Analog/Digital mode.: Digital mode. */
#define PIO22_DIGIMODE_DIGITAL 0x01u
/*!
 * @brief Controls input glitch filter.: Filter disabled. No input filtering is done. */
#define PIO22_FILTEROFF_DISABLED 0x01u
/*!
 * @brief Selects pin function.: Alternative connection 4. */
#define PIO22_FUNC_ALT4 0x04u
/*!
 * @brief Input polarity.: Disabled. Input function is not inverted. */
#define PIO22_INVERT_DISABLED 0x00u
/*!
 * @brief Controls open-drain mode.: Normal. Normal push-pull output */
#define PIO22_OD_NORMAL 0x00u
/*!
 * @brief
 * Driver slew rate.
 * : Standard mode, output slew rate control is enabled.
 * More outputs can be switched simultaneously.
 */
#define PIO22_SLEW_STANDARD 0x00u

/*! @name CTIMER1_MAT1 (coord C3), J9[6]/LED3/P2_2-CT1MAT1-USR_LED3
  @{ */
#define BOARD_INITPWM_LED3_PERIPHERAL CTIMER1                       /*!<@brief Device name: CTIMER1 */
#define BOARD_INITPWM_LED3_SIGNAL MATCH                             /*!<@brief CTIMER1 signal: MATCH */
#define BOARD_INITPWM_LED3_CHANNEL 1                                /*!<@brief CTIMER1 MATCH channel: 1 */
#define BOARD_INITPWM_LED3_PIN_NAME CTIMER1_MAT1                    /*!<@brief Pin name */
#define BOARD_INITPWM_LED3_LABEL "J9[6]/LED3/P2_2-CT1MAT1-USR_LED3" /*!<@brief Label */
#define BOARD_INITPWM_LED3_NAME "LED3"                              /*!<@brief Identifier name */
                                                                    /* @} */

/*!
 * @brief Configures pin routing and optionally pin electrical features.
 *
 */
void BOARD_InitPWM(void); /* Function assigned for the Cortex-M4F */

#if defined(__cplusplus)
}
#endif

/*!
 * @}
 */
#endif /* _PIN_MUX_H_ */

/***********************************************************************************************************************
 * EOF
 **********************************************************************************************************************/
